# WhatsappBOT
It's an automated whatsapp bot which can serve as chatbot and can perform search operations on google, youtube, wikipedia 

It can automatically fetch for new messages and reply to the user.

Libraries used - 

Chatterbot - For chatBot

Selenium - for controling browser and scrapping and sending messages

os - to run existing chrome session

Important - 

1- you just need to login to chrome using whatsapp web Once. This doesn't run on chromedriver and hence you 

    you won't have to login again and again. 

2 - create a whatsapp group with name "Standby".

3 - To train the bot for personal use please refer to ::


    please contact me at srivastavas08@gmail.com


4 - Nothing else needed just enjoy